# tagged-users

- Exactly **64 lines of code** (including comments)<img src="https://media.giphy.com/media/3MdUtlnqBWi8YnkIig/giphy.gif" align="right">
- Works on **Linux** and **MacOS**
- Only **4KB**
- Able to be piped out to other programs
<br>
<br>
<br>
<br>
<br>
<br>
<br>

## Why?

Many times, the person who posted the photo, puts all the
tags very close to each other, which makes is very difficult
click on the username.

Here is an example of what I mean:

![](https://user-images.githubusercontent.com/27065646/59212097-ca3d5480-8bb1-11e9-8481-07bd3784e689.png)

Honestly, it is almost impossible to click on some of the tags.

## Installation
```python
pip3 install tagged-users
```

## Usage
```
usage: tagged-users [-h] url

Get all the usernames of the people who got tagged in an Instagram post

positional arguments:
  url         URL to Instagram post

optional arguments:
  -h, --help  show this help message and exit
```

## License
MIT License

Copyright (c) 2019 Siddharth Dushantha
